#include "prjlibs-c/standards.h"
#include <unistd.h>
#include <limits.h>
#include <errno.h>

#include "skalibs/include/stddjb.h"
#include "prjlibs-c/constants.h"
#include "fdtools.h"

extern void check_exit_exec(char** argv);

char const* PROG="setblock";

int main(int argc, char** argv) {
  for (argv+=(argc!=0);; ++argv) {
    char const* arg=*argv;
    int block;
    unsigned int fd, len;

    check_exit_exec(argv);

    block=(arg[0]=='+');
    if (arg[0]!='+' && arg[0]!='-')
      strerr_die3x(100, usage, PROG, "{+|-}fd [...] [: program ...]");

    ++arg;
    len=scan_uint(arg, &fd);
    if (len==0 || arg[len]!='\0' || fd>INT_MAX)
      strerr_die3x(100, PROG, ": descriptor malformed: ", arg);

    switch (setblock(fd, block)) {
      case setblock_success: break;
      case setblock_getfl:
        strerr_die5sys(errstat, PROG, err_unable,
                       "get flags for descriptor ", arg, ": ");
      case setblock_setfl:
        strerr_die5sys(errstat, PROG, err_unable,
                       "set flags for descriptor ", arg, ": ");
      default:
        strerr_die3sys(100, PROG, err_unknown, ": ");
    }
  }
}
